@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 import os
 from .sql import SQLQueue
 from .logging import LogHandle
-from . import FileParser
+from .filehandler import FileParser
 from exchangelib import Credentials as Exch_Cred, Configuration, DELEGATE
 from exchangelib.errors import UnauthorizedError, TransportError
 from traceback import format_exc
